DependencySpec

Struct DependencySpec 

pub struct DependencySpec {
    pub name: Span<Arc<str>>,
    pub version_or_digest: Option<VersionRequirement>,
    pub workspace: bool,
    pub path: Option<Span<Uri>>,
    pub git: Option<Span<Uri>>,
    pub branch: Option<Span<Arc<str>>>,
    pub rev: Option<Span<Arc<str>>>,
    pub linkage: Option<Span<Linkage>>,
}
Represents information about a project dependency needed to resolve it to a Miden package

Fields

name: Span<Arc<str>>

The name of the dependency package

version_or_digest: Option<VersionRequirement>

The version requirement specified for this dependency

workspace: bool

Whether or not the version requirement is inherited from the containing workspace

path: Option<Span<Uri>>

If present, specifies the path from which this dependency should be loaded

git: Option<Span<Uri>>

If present, specifies the URI of the git repository to clone in order to load this dependency.

branch: Option<Span<Arc<str>>>

If present, specifies the branch of the git repository to checkout when loading this dependency from the URI specified by git.

NOTE: This field is only valid when specified along with git, and may not be used in conjunction with rev.

rev: Option<Span<Arc<str>>>

If present, specifies the revision of the git repository to checkout when loading this dependency from the URI specified by git.

NOTE: This field is only valid when specified along with git, and may not be used in conjunction with branch.

linkage: Option<Span<Linkage>>

If present, specifies the desired linkage for this dependency during assembly

Implementations

Source

impl DependencySpec

pub fn version(&self) -> Option<&VersionRequirement>

Returns the version constraint to apply to this dependency

pub fn inherits_workspace_version(&self) -> bool

Returns true if this dependency inherits its version requirement from a parent workspace

pub fn is_host_resolved(&self) -> bool

Returns true if this dependency must be resolved using a host-provided resolver

pub fn is_path(&self) -> bool

Returns true if this dependency specifies a local filesystem path

pub fn is_git(&self) -> bool

Returns true if this dependency specifies a git repository