pub struct ProjectFile {
pub source_file: Option<Arc<SourceFile>>,
pub package: PackageTable,
pub config: PackageConfig,
pub lib: Option<Span<LibTarget>>,
pub bins: Vec<Span<BinTarget>>,
pub profiles: Vec<Profile>,
}Expand description
Represents the miden-project.toml structure of an individual package
Fields
source_file: Option<Arc<SourceFile>>The original source file this was parsed from, if applicable/known
package: PackageTableContents of the [package] table
config: PackageConfigContents of tables shared with workspace-level miden-project.toml, e.g. [dependencies]
and [lints]
lib: Option<Span<LibTarget>>The library target of this project, if applicable
bins: Vec<Span<BinTarget>>The binary targets of this project, if applicable
profiles: Vec<Profile>The set of build profiles defined in this file
Implementations
Sourceimpl ProjectFile
Parsing
impl ProjectFile
Parsing
Sourcepub fn parse(source: Arc<SourceFile>) -> Result<Self, Report>
pub fn parse(source: Arc<SourceFile>) -> Result<Self, Report>
Parse a ProjectFile from the provided TOML source file, generally miden-project.toml
If successful, the contents of the manifest are semantically valid, with the following caveats:
- Inherited properties from the workspace-level are assumed to exist and be correct. It is up to the caller to compute the concrete property values and validate them at that point.
pub fn get_or_inherit_version( &self, source: Arc<SourceFile>, workspace: Option<&WorkspaceFile>, ) -> Result<Span<SemVer>, Report>
pub fn get_or_inherit_description( &self, source: Arc<SourceFile>, workspace: Option<&WorkspaceFile>, ) -> Result<Option<Arc<str>>, Report>
pub fn extract_dependencies( &self, source: Arc<SourceFile>, workspace: Option<&WorkspaceFile>, ) -> Result<Vec<Dependency>, Report>
pub fn extract_library_target(&self) -> Result<Option<Span<Target>>, Report>
pub fn extract_executable_targets(&self) -> Vec<Span<Target>>