pub struct WorkspaceFile {
pub source_file: Option<Arc<SourceFile>>,
pub workspace: WorkspaceTable,
pub profiles: Vec<Profile>,
}Expand description
Represents a workspace-level miden-project.toml file
Fields
source_file: Option<Arc<SourceFile>>The source file this was parsed from, if applicable/known
workspace: WorkspaceTableThe contents of the [workspace] table
profiles: Vec<Profile>The contents of the [profile] table
Implementations
Sourceimpl WorkspaceFile
Parsing
impl WorkspaceFile
Parsing
Sourcepub fn parse(source: Arc<SourceFile>) -> Result<Self, Report>
pub fn parse(source: Arc<SourceFile>) -> Result<Self, Report>
Parse a ProjectFile from the provided TOML source file, generally miden-project.toml
If successful, the contents of the manifest are semantically valid, with the following caveats:
- Inherited properties from the workspace-level are assumed to exist and be correct. It is up to the caller to compute the concrete property values and validate them at that point.