Linkage

Enum Linkage 

#[repr(u8)]
pub enum Linkage { Dynamic = 0, Static = 1, }
This represents the way in which a dependent will link against a dependency during assembly.

Variants



Dynamic = 0

Link against the target package dynamically, i.e. it is expected that the package will be provided to the VM at runtime so that it is available for the dependent.



Static = 1

Link the contents of the target package into the dependent package, as if they were defined as part of the dependent.

This linkage mode ensures that the dependency does not have to be provided to the VM separately in order to execute code from the dependent.

Implementations

Source

impl Linkage

pub const fn as_str(&self) -> &'static str

Get the string representation of this linkage