#[non_exhaustive]#[repr(u8)]pub enum TargetType {
Library = 0,
Executable = 1,
Kernel = 2,
AccountComponent = 3,
NoteScript = 4,
TransactionScript = 5,
}Expand description
The type of a specific target provided by the current project
This describes how a package produced from this project can be used (e.g. as an account component, a note script, etc.).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Library = 0
A generic code library
Executable = 1
An executable program
Kernel = 2
A kernel library
AccountComponent = 3
An account component
NoteScript = 4
A note script
TransactionScript = 5
A transaction script
Implementations
Sourceimpl TargetType
impl TargetType
Sourcepub const fn is_executable(&self) -> bool
pub const fn is_executable(&self) -> bool
Returns true if the target is an executable artifact
Sourcepub const fn is_library(&self) -> bool
pub const fn is_library(&self) -> bool
Returns true if the target is a library-like artifact