pub struct Dependency { /* private fields */ }Expand description
Represents a project/package dependency declaration
Implementations
Sourceimpl Dependency
impl Dependency
Sourcepub const fn new(
name: Span<Arc<str>>,
version: DependencyVersionScheme,
linkage: Linkage,
) -> Self
pub const fn new( name: Span<Arc<str>>, version: DependencyVersionScheme, linkage: Linkage, ) -> Self
Construct a new Dependency with the given name and version scheme
Sourcepub fn scheme(&self) -> &DependencyVersionScheme
pub fn scheme(&self) -> &DependencyVersionScheme
Get the versioning scheme/requirement for this dependency
Sourcepub fn required_version(&self) -> Option<VersionRequirement>
pub fn required_version(&self) -> Option<VersionRequirement>
Get the version requirement for this dependency, if one was given