pub struct Package { /* private fields */ }Expand description
The representation of an individual package in a Miden project
Implementations
Sourceimpl Package
Accessors
impl Package
Accessors
Sourcepub fn description(&self) -> Option<Arc<str>>
pub fn description(&self) -> Option<Arc<str>>
Get the description of this package, if specified
Sourcepub fn dependencies(&self) -> &[Dependency]
pub fn dependencies(&self) -> &[Dependency]
Get the set of dependencies this package requires
Sourcepub fn num_dependencies(&self) -> usize
pub fn num_dependencies(&self) -> usize
Get the number of dependencies this package requires
Sourcepub fn lints(&self) -> &MetadataSet
pub fn lints(&self) -> &MetadataSet
Get a reference to the linter metadata configured for this package
Sourcepub fn metadata(&self) -> &MetadataSet
pub fn metadata(&self) -> &MetadataSet
Get a reference to the custom metadata configured for this package
Sourcepub fn profiles(&self) -> &[Profile]
pub fn profiles(&self) -> &[Profile]
Get a reference to the build profiles configured for this package
Sourcepub fn library_target(&self) -> Option<&Span<Target>>
pub fn library_target(&self) -> Option<&Span<Target>>
Get a reference to the library build target provided by this package
Sourcepub fn executable_targets(&self) -> &[Span<Target>]
pub fn executable_targets(&self) -> &[Span<Target>]
Get a reference to the executable build targets provided by this package
Sourcepub fn manifest_path(&self) -> Option<&Path>
pub fn manifest_path(&self) -> Option<&Path>
Get the location of the manifest this package was loaded from, if known/applicable.
Sourceimpl Package
Parsing
impl Package
Parsing
Sourcepub fn load(source: Arc<SourceFile>) -> Result<Box<Self>, Report>
pub fn load(source: Arc<SourceFile>) -> Result<Box<Self>, Report>
Load a package from source, expected to be a standalone package-level miden-project.toml
manifest.
Sourcepub fn load_from_workspace(
source: Arc<SourceFile>,
workspace: &WorkspaceFile,
) -> Result<Box<Self>, Report>
pub fn load_from_workspace( source: Arc<SourceFile>, workspace: &WorkspaceFile, ) -> Result<Box<Self>, Report>
Load a package from source, expected to be a package-level miden-project.toml manifest
which is presumed to be a member of workspace for purposes of configuration inheritance.