PackageResolver

Struct PackageResolver 

pub struct PackageResolver<'a> { /* private fields */ }
As implied by the name, this is the implementation of the dependency/package resolver.

The resolver is constructed for a specific root package, along with a reference to the current state of the package index. Once constructed, you then ask the resolver for the dependencies of the given package using PackageResolver::resolve. It is then up to the caller to take those package and version selections and do something with them, typically fetching the actual package content and using it for program execution or assembly of a new package.

Implementations

Source

impl<'a> PackageResolver<'a>

Construction

pub fn for_package_in_workspace( package: &'a Package, workspace: &'a Workspace, index: &'a PackageIndex, ) -> Self

Create a PackageResolver for package in workspace, using index.

It is assumed that the caller has already:

  1. Ensured that index has been seeded with package, along with other members of workspace, and all versions of all packages known to the system that may be referenced as dependencies, directly or transitively.
  2. Verified that package is a member of workspace. While resolution can still succeed if that isn’t the case, it may cause unexpected conflicts or selections to occur due to the special prioritization given to workspace members.
pub fn for_package(package: &'a Package, index: &'a PackageIndex) -> Self

Create a PackageResolver for package, using index.

For packages that are members of a workspace, you should prefer Self::for_package_in_workspace.

It is assumed that the caller has already:

  1. Ensured that index has been seeded with package, along with all versions of all packages known to the system that may be referenced as dependencies, directly or transitively.
Source

impl<'a> PackageResolver<'a>

Dependency resolution

pub fn resolve( self, ) -> Result<SelectedDependencies<Self>, DependencyResolutionError>

pub fn resolve_for( &self, package: impl Into<PackageId>, version: SemVer, ) -> Result<SelectedDependencies<Self>, DependencyResolutionError>

Resolve dependencies for package with the given version.

If successful, this returns a map of PackageId to Version for all dependencies required by package, transitively.

If unsuccesssful, a DependencyResolutionError is returned that indicates why it failed.