Profile

Struct Profile 

pub struct Profile { /* private fields */ }
Represents configuration options for a specific build profile, e.g. release

Implementations

Source

impl Profile

Constructors

pub fn new(name: Span<Arc<str>>) -> Self

Create a new profile called name, with all configuration options set to their defaults.

pub fn inherit(name: Span<Arc<str>>, parent: &Self) -> Self

Create a profile called name, with all configuration options inherited from parent

NOTE: Any changes made to parent after this new profile is created are not automatically inherited - the “inheritance” here is simply used to initialize the options this profile starts with.

pub fn release() -> Self

Get the default release profile

pub fn from_ast( ast: &Profile, source: Arc<SourceFile>, inheritable: &[Profile], ) -> Result<Self, Report>

pub fn merge(&mut self, other: &Self)

Merge configuration from other into self.

This has the effect of overriding any options in self which have different values in other.

Source

impl Profile

Mutations

pub fn enable_debug_info(&mut self, yes: bool) -> &mut Self

Enable emission of debug information under this profile

pub fn enable_trim_paths(&mut self, yes: bool) -> &mut Self

Enable trimmming of file paths in debug info under this profile

Source

impl Profile

Accessors

pub fn name(&self) -> &Arc<str>

Get the name of this profile

pub const fn should_emit_debug_info(&self) -> bool

Returns true if this profile is configured so that we should emit debug information.

pub const fn should_trim_paths(&self) -> bool

Returns true if this profile is configured so that we should trim file paths in debug information to be relative to the current working directory.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: ?Sized + Ord, Span<Arc<str>>: Borrow<Q> + Ord,

Returns true if key is defined in the custom metadata associated with this profile.

pub fn get<Q>(&self, key: &Q) -> Option<&Span<Value>>
where Q: ?Sized + Ord, Span<Arc<str>>: Borrow<Q> + Ord,

Returns the value associated with key in the custom metadata associated with this profile.

Returns None if no value is found for key.