pub struct ProjectDependencyGraph { /* private fields */ }Expand description
The ProjectDependencyGraph represents a materialized dependency graph rooted at a specific package.
Each node in the graph corresponds to a specific package version, and describes:
- What packages it depends on, and with what linkage
- The provenance of the package, i.e. whether the package was sourced from a pre-assembled artifact on the local filesystem; assembled from source that is present on the local filesystem (and where those sources came from); or was fetched from the package registry.
The assembler uses this dependency graph both for validation, and to ensure that all dependencies of a package are properly linked.
See ProjectDependencyGraphBuilder for more details on constructing a ProjectDependencyGraph.
Implementations
Sourceimpl ProjectDependencyGraph
impl ProjectDependencyGraph
Sourcepub fn nodes(&self) -> &BTreeMap<PackageId, ProjectDependencyNode>
pub fn nodes(&self) -> &BTreeMap<PackageId, ProjectDependencyNode>
Get the nodes of the underlying graph
Sourcepub fn get(&self, package: &PackageId) -> Option<&ProjectDependencyNode>
pub fn get(&self, package: &PackageId) -> Option<&ProjectDependencyNode>
Get the node corresponding to package