pub struct ProjectDependencyNode {
pub name: PackageId,
pub version: SemVer,
pub dependencies: Vec<ProjectDependencyEdge>,
pub provenance: ProjectDependencyNodeProvenance,
}Expand description
Represents information about a single package in a ProjectDependencyGraph
Fields
name: PackageIdThe name of the package
version: SemVerThe semantic version of the package
dependencies: Vec<ProjectDependencyEdge>Known dependencies of this package, which are also found in the graph.
provenance: ProjectDependencyNodeProvenanceThe provenance of this package