pub struct Target {
pub ty: TargetType,
pub name: Span<Arc<str>>,
pub namespace: Span<Arc<Path>>,
pub path: Option<Span<Uri>>,
}Expand description
Represents build target configuration
Fields
ty: TargetTypename: Span<Arc<str>>The effective name of this target
If unspecified in the project file, the name is the same as namespace
The name must be unique within a project
namespace: Span<Arc<Path>>The namespace root for this target
path: Option<Span<Uri>>The path from the project manifest to the root source file for this target
If not provided, it is expected that source modules will be provided to the assembler
through other means. For example, midenc will compile Rust code to MASM, and then provide
the MASM modules to an instantiated assembler when assembling this project.