pub struct Version {
pub version: Version,
pub digest: Option<LexicographicWord>,
}Expand description
The representation of versioning information associated with packages in the package index.
This type provides the means by which dependency resolution can satisfy versioning constraints on packages using either semantic version constraints or explicit package digests simultaneously.
All packages have an associated semantic version. Packages which have been assembled to MAST, also have an associated content digest. However, for the purposes of indexing and dependency resolution, we cannot assume that all packages have a content digest (as they may not have been assembled yet), and so this type is used to represent versions within the index/resolver so that it can:
- Satisfy requirements for a package that has a specific digest
- Record the exact published identity of a canonical package artifact as
semver#digest - Provide a total ordering for package versions that may or may not include a specific digest
Fields
version: VersionThe semantic version information
This is the canonical human-facing version for a package.
digest: Option<LexicographicWord>The content digest for this version, if known.
This is the most precise version for a package, and uniquely identifies the canonical published artifact associated with a semantic version.
Implementations
Sourceimpl Version
impl Version
Sourcepub fn new(version: Version, digest: Word) -> Version
pub fn new(version: Version, digest: Word) -> Version
Construct a Version from its component parts.
Sourcepub fn without_digest(&self) -> Version
pub fn without_digest(&self) -> Version
Get a Version without an attached digest for comparison purposes
Sourcepub fn as_range(&self) -> Range<Version>
pub fn as_range(&self) -> Range<Version>
Get a core::ops::Range which can be used to select all available versions with the same semantic version, but with possibly-differing digests
Sourcepub fn is_semantically_equivalent(&self, other: &Version) -> bool
pub fn is_semantically_equivalent(&self, other: &Version) -> bool
Returns true if self and other are equivalent with regards to semantic versioning
Sourcepub fn satisfies(&self, requirement: &VersionRequirement) -> bool
pub fn satisfies(&self, requirement: &VersionRequirement) -> bool
Check if this version satisfies the given requirement.
Version requirements are expressed as either a semantic version constraint OR a specific content digest.