pub struct VersionSet { /* private fields */ }Expand description
This type is an implementation detail of the dependency resolver provided by
super::PackageIndex.
A VersionSet, as implied by the name, provides set semantics for semantic versioning ranges that may also be further constrained by specific content digests that are considered to be part of the set.
- The empty set is represented as a range that cannot contain any version
- The complete (aka “full”) set is represented as an unbounded range with an empty content
digest filter, equivalent to the semantic versioning constraint
* - Set intersection is performed by finding the overlap in the ranges of the two sets, and then if either set has a content digest filter, only permitting content digests that are present in both sets. It is not guaranteed that a given content digest is included in the semantic version intersection, rather either the digest or the semantic version of the intersection is used for matching a package.
- Set complement is performed by negating the range of versions included in the set. The resulting set will always have an empty content digest filter.
- Set containment for a version
vis determined as follows:- If the semantic version component of
vis covered by any range in the set, it is provisionally considered to be contained in the set, IFF - If the set specifies a content digest filter, then
vmust have a content digest component that matches that filter.
- If the semantic version component of
Implementations