pub struct Workspace { /* private fields */ }Expand description
Represents a Miden project workspace.
Workspaces are comprised of one or more sub-projects that define the member packages of the workspace.
Implementations
Sourceimpl Workspace
Accessors
impl Workspace
Accessors
Sourcepub fn manifest_path(&self) -> Option<&Path>
pub fn manifest_path(&self) -> Option<&Path>
Return the path of the workspace manifest, if known.
Sourcepub fn workspace_root(&self) -> Option<&Path>
pub fn workspace_root(&self) -> Option<&Path>
Return the path of the directory containing the workspace manifest
Sourcepub fn members(&self) -> &[Arc<Package>]
pub fn members(&self) -> &[Arc<Package>]
Get the set of packages which are members of this workspace