pub enum MidenProject {
Workspace(Box<WorkspaceFile>),
Package(Box<ProjectFile>),
}Expand description
Represents all possible variants of miden-project.toml
Variants
Workspace(Box<WorkspaceFile>)
A workspace-level configuration file.
On its own, a workspace-level miden-project.toml does define a package, instead packages
are derived from the members of the workspace.
Package(Box<ProjectFile>)
A package-level configuration file.
A miden-project.toml of this variety defines a package, and may reference/override any
workspace-level dependencies, lints, or build profiles.
Implementations
Sourceimpl MidenProject
Accessors
impl MidenProject
Accessors
Sourcepub fn is_workspace(&self) -> bool
pub fn is_workspace(&self) -> bool
Returns true if this project is actually a multi-project workspace
Sourceimpl MidenProject
Parsing
impl MidenProject
Parsing
Sourcepub fn parse(source: Arc<SourceFile>) -> Result<Self, Report>
pub fn parse(source: Arc<SourceFile>) -> Result<Self, Report>
Parse a MidenProject from the provided TOML source file, generally miden-project.toml
If successful, the contents of the manifest are semantically valid, with the following caveats:
- If parsing a workspace-level configuration, the workspace members are not checked, so it is up to the caller to iterate over the member paths, and parse/validate their respective configurations.
- If parsing an individual project configuration which belongs to a workspace, inherited properties from the workspace-level are assumed to exist and be correct. It is up to the caller to compute the concrete property values and validate them at that point.