pub enum DependencyVersionScheme {
Registry(VersionRequirement),
Workspace {
member: Span<Uri>,
},
Path {
path: Span<Uri>,
version: Option<VersionRequirement>,
},
Git {
repo: Span<Uri>,
revision: Span<GitRevision>,
version: Option<Span<VersionReq>>,
},
}Expand description
Represents the versioning requirement and resolution method for a specific dependency.
Variants
Registry(VersionRequirement)
Resolve the given semantic version requirement or digest using the configured package registry, to an assembled Miden package artifact.
Resolution of packages using this scheme relies on the specific implementation of the package registry in use, which can vary depending on context.
Workspace
Resolve the given path to a member of the current workspace.
Path
Resolve the given path to a Miden project/workspace, or assembled Miden package artifact.
Fields
path: Span<Uri>The path to a Miden project directory containing a miden-project.toml OR a Miden
package file (i.e. a file with the .masp extension, as produced by the assembler).
version: Option<VersionRequirement>If specified, the version of the referenced project/package must match this version requirement.
If unspecified, the version requirement is presumed to be an exact match for the version found in the package/project at the given path.
Git
Resolve the given Git repository to a Miden project/workspace.
Fields
revision: Span<GitRevision>The specific revision to clone.
version: Option<Span<VersionReq>>If specified, the version declared in the manifest found in the cloned repository must match this version requirement.
If unspecified, the version requirement is presumed to be an exact match for the version found in the project manifest of the cloned repo.
Implementations
Sourceimpl DependencyVersionScheme
impl DependencyVersionScheme
Sourcepub fn try_from_in_workspace(
spec: Span<&DependencySpec>,
workspace: &WorkspaceFile,
) -> Result<Self, InvalidDependencySpecError>
pub fn try_from_in_workspace( spec: Span<&DependencySpec>, workspace: &WorkspaceFile, ) -> Result<Self, InvalidDependencySpecError>
Parse a dependency spec into DependencyVersionScheme, taking into account workspace context.