pub enum VersionRequirement {
Semantic(Span<VersionReq>),
Digest(Span<Word>),
}Expand description
Represents a requirement on a specific version (or versions) of a dependency.
Variants
Semantic(Span<VersionReq>)
A semantic versioning constraint, e.g. ~> 0.1
In general, this is meant to indicate that any version of a package that satisfies the version constraint can be used to resolve the dependency.
This form of constraint also permits us to compile a dependency from source, so long as the semantic versioning constraint is satisfied.
Digest(Span<Word>)
The most precise and onerous form of versioning constraint.
This requires that the dependency’s package digest exactly matches the one provided here.
Digest constraints also effectively require that the dependency already be compiled to a
Miden package, as digests are derived from the MAST of a compiled package. This means that
when the dependency is resolved, we must be able to find a .masp file with the expected
digest.
Implementations