Package

Struct Package 

pub struct Package { /* private fields */ }
The representation of an individual package in a Miden project

Implementations

Source

impl Package

Constructor

pub fn new(name: impl Into<PackageId>, default_target: Target) -> Box<Self>

Create a new Package named name with the given default target.

The resulting package will have a default version of 0.0.0, no dependencies, and an initial set of profiles that consist of the default development and release profiles. The project will have no other configuration set up - that must be done in subsequent steps.

pub fn with_version(self: Box<Self>, version: SemVer) -> Box<Self>

Specify a version for this package during initial construction

pub fn with_lints(self: Box<Self>, lints: MetadataSet) -> Box<Self>

Provide the lint configuration for this package during initial construction

pub fn with_metadata(self: Box<Self>, metadata: MetadataSet) -> Box<Self>

Provide the metadata for this package during initial construction

pub fn with_targets( self: Box<Self>, targets: impl IntoIterator<Item = Target>, ) -> Box<Self>

Add targets to this package during initial construction

This function will panic if any of the given targets conflict with existing targets or each other.

pub fn with_profile(self: Box<Self>, profile: Profile) -> Box<Self>

Add a profile to this package during initial construction

If the given profile matches an existing profile, it will be merged over the top of it.

pub fn with_dependencies( self: Box<Self>, dependencies: impl IntoIterator<Item = Dependency>, ) -> Box<Self>

Add dependencies to this package during initial construction

This function will panic if any of the given dependencies conflict with existing deps or each other.

Source

impl Package

Accessors

pub fn name(&self) -> Span<PackageId>

Get the name of this package

pub fn version(&self) -> Span<&SemVer>

Get the semantic version of this package

pub fn description(&self) -> Option<Arc<str>>

Get the description of this package, if specified

pub fn set_description(&mut self, description: impl Into<Arc<str>>)

Set the description of this package, if specified

pub fn dependencies(&self) -> &[Dependency]

Get the set of dependencies this package requires

pub fn num_dependencies(&self) -> usize

Get the number of dependencies this package requires

pub fn lints(&self) -> &MetadataSet

Get a reference to the linter metadata configured for this package

pub fn metadata(&self) -> &MetadataSet

Get a reference to the custom metadata configured for this package

pub fn profiles(&self) -> &[Profile]

Get a reference to the build profiles configured for this package

pub fn get_profile(&self, name: &str) -> Option<&Profile>

Returns a profile with the specified name, or None if such a profile does not exist in this package.

pub fn library_target(&self) -> Option<&Span<Target>>

Get a reference to the library build target provided by this package

pub fn executable_targets(&self) -> &[Span<Target>]

Get a reference to the executable build targets provided by this package

pub fn manifest_path(&self) -> Option<&Path>

Get the location of the manifest this package was loaded from, if known/applicable.

Source

impl Package

Parsing

pub fn load(source: Arc<SourceFile>) -> Result<Box<Self>, Report>

Load a package from source, expected to be a standalone package-level miden-project.toml manifest.

pub fn load_from_workspace( source: Arc<SourceFile>, workspace: &WorkspaceFile, ) -> Result<Box<Self>, Report>

Load a package from source, expected to be a package-level miden-project.toml manifest which is presumed to be a member of workspace for purposes of configuration inheritance.

Source

impl Package

pub fn to_toml(&self) -> Result<String, Report>

Pretty print this Package in TOML format.

The output of this function is not guaranteed to be identical to the way the original manifest (if one exists) was written, i.e. it may emit keys that are optional or that contain default or inherited values.