pub struct PackageResolver<'a> { /* private fields */ }Expand description
As implied by the name, this is the implementation of the dependency/package resolver.
The resolver is constructed for a specific root package, along with a reference to the current
state of the package index. Once constructed, you then ask the resolver for the dependencies
of the given package using PackageResolver::resolve. It is then up to the caller to take
those package and version selections and do something with them, typically fetching the actual
package content and using it for program execution or assembly of a new package.
Implementations
Sourceimpl<'a> PackageResolver<'a>
Construction
impl<'a> PackageResolver<'a>
Construction
Sourcepub fn for_package_in_workspace(
package: &'a Package,
workspace: &'a Workspace,
index: &'a PackageIndex,
) -> Self
pub fn for_package_in_workspace( package: &'a Package, workspace: &'a Workspace, index: &'a PackageIndex, ) -> Self
Create a PackageResolver for package in workspace, using index.
It is assumed that the caller has already:
- Ensured that
indexhas been seeded withpackage, along with other members ofworkspace, and all versions of all packages known to the system that may be referenced as dependencies, directly or transitively. - Verified that
packageis a member ofworkspace. While resolution can still succeed if that isn’t the case, it may cause unexpected conflicts or selections to occur due to the special prioritization given to workspace members.
Sourcepub fn for_package(package: &'a Package, index: &'a PackageIndex) -> Self
pub fn for_package(package: &'a Package, index: &'a PackageIndex) -> Self
Create a PackageResolver for package, using index.
For packages that are members of a workspace, you should prefer
Self::for_package_in_workspace.
It is assumed that the caller has already:
- Ensured that
indexhas been seeded withpackage, along with all versions of all packages known to the system that may be referenced as dependencies, directly or transitively.
Sourceimpl<'a> PackageResolver<'a>
Dependency resolution
impl<'a> PackageResolver<'a>
Dependency resolution
pub fn resolve( self, ) -> Result<SelectedDependencies<Self>, DependencyResolutionError>
Sourcepub fn resolve_for(
&self,
package: impl Into<PackageId>,
version: SemVer,
) -> Result<SelectedDependencies<Self>, DependencyResolutionError>
pub fn resolve_for( &self, package: impl Into<PackageId>, version: SemVer, ) -> Result<SelectedDependencies<Self>, DependencyResolutionError>
Resolve dependencies for package with the given version.
If successful, this returns a map of PackageId to Version for all dependencies required
by package, transitively.
If unsuccesssful, a DependencyResolutionError is returned that indicates why it failed.