pub struct Profile { /* private fields */ }Expand description
Represents configuration options for a specific build profile, e.g. release
Implementations
Sourceimpl Profile
Constructors
impl Profile
Constructors
Sourcepub fn new(name: Span<Arc<str>>) -> Self
pub fn new(name: Span<Arc<str>>) -> Self
Create a new profile called name, with all configuration options set to their defaults.
Sourcepub fn inherit(name: Span<Arc<str>>, parent: &Self) -> Self
pub fn inherit(name: Span<Arc<str>>, parent: &Self) -> Self
Create a profile called name, with all configuration options inherited from parent
NOTE: Any changes made to parent after this new profile is created are not automatically
inherited - the “inheritance” here is simply used to initialize the options this profile
starts with.
pub fn from_ast( ast: &Profile, source: Arc<SourceFile>, inheritable: &[Profile], ) -> Result<Self, Report>
Sourceimpl Profile
Mutations
impl Profile
Mutations
Sourcepub fn enable_debug_info(&mut self, yes: bool) -> &mut Self
pub fn enable_debug_info(&mut self, yes: bool) -> &mut Self
Enable emission of debug information under this profile
Sourcepub fn enable_trim_paths(&mut self, yes: bool) -> &mut Self
pub fn enable_trim_paths(&mut self, yes: bool) -> &mut Self
Enable trimmming of file paths in debug info under this profile
Sourceimpl Profile
Accessors
impl Profile
Accessors
Sourcepub const fn should_emit_debug_info(&self) -> bool
pub const fn should_emit_debug_info(&self) -> bool
Returns true if this profile is configured so that we should emit debug information.
Sourcepub const fn should_trim_paths(&self) -> bool
pub const fn should_trim_paths(&self) -> bool
Returns true if this profile is configured so that we should trim file paths in debug information to be relative to the current working directory.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if key is defined in the custom metadata associated with this profile.