pub struct Target {
pub ty: TargetType,
pub name: Span<Arc<str>>,
pub namespace: Span<Arc<Path>>,
pub path: Span<Uri>,
}Expand description
Represents build target configuration
Fields
ty: TargetTypename: Span<Arc<str>>The effective name of this target
If unspecified in the project file, the name is the same as namespace
The name must be unique within a project
namespace: Span<Arc<Path>>The namespace root for this target
path: Span<Uri>The path from the project manifest to the root source file for this target
The path can be to a source file written in any language, e.g. for MASM it might refer to
mod.masm, while for Rust it might refer to src/lib.rs - as long as an appropriate
source provider is registered with the assembler.
Implementations
Sourceimpl Target
impl Target
Sourcepub fn executable(name: impl Into<Arc<str>>, uri: Uri) -> Self
pub fn executable(name: impl Into<Arc<str>>, uri: Uri) -> Self
Construct a new executable target named name and given source uri
Sourcepub fn library(namespace: impl Into<Arc<Path>>, uri: Uri) -> Self
pub fn library(namespace: impl Into<Arc<Path>>, uri: Uri) -> Self
Construct a new library target named name with the given namespace and source uri
Sourcepub fn new(
ty: TargetType,
name: impl Into<Arc<str>>,
namespace: impl Into<Arc<Path>>,
uri: Uri,
) -> Self
pub fn new( ty: TargetType, name: impl Into<Arc<str>>, namespace: impl Into<Arc<Path>>, uri: Uri, ) -> Self
Construct a new target of type ty, with the given name, namespace and source uri
Sourcepub const fn is_executable(&self) -> bool
pub const fn is_executable(&self) -> bool
Returns true if this target is an executable target
Sourcepub const fn is_library(&self) -> bool
pub const fn is_library(&self) -> bool
Returns true if this target is a non-executable target
Sourcepub fn append_build_provenance_projection(&self, out: &mut String)
pub fn append_build_provenance_projection(&self, out: &mut String)
Append the selected target fields that affect package artifact reuse to out.