pub struct Target {
pub ty: TargetType,
pub name: Span<Arc<str>>,
pub namespace: Span<Arc<Path>>,
pub path: Option<Span<Uri>>,
}Expand description
Represents build target configuration
Fields
ty: TargetTypename: Span<Arc<str>>The effective name of this target
If unspecified in the project file, the name is the same as namespace
The name must be unique within a project
namespace: Span<Arc<Path>>The namespace root for this target
path: Option<Span<Uri>>The path from the project manifest to the root source file for this target
If not provided, it is expected that source modules will be provided to the assembler
through other means. For example, midenc will compile Rust code to MASM, and then provide
the MASM modules to an instantiated assembler when assembling this project.
Implementations
Sourceimpl Target
impl Target
Sourcepub fn executable(name: impl Into<Arc<str>>) -> Self
pub fn executable(name: impl Into<Arc<str>>) -> Self
Construct a new virtual executable target named name
Sourcepub fn library(namespace: impl Into<Arc<Path>>) -> Self
pub fn library(namespace: impl Into<Arc<Path>>) -> Self
Construct a new virtual library target named name with namespace namespace
Sourcepub fn virtual(
ty: TargetType,
name: impl Into<Arc<str>>,
namespace: impl Into<Arc<Path>>,
) -> Self
pub fn virtual( ty: TargetType, name: impl Into<Arc<str>>, namespace: impl Into<Arc<Path>>, ) -> Self
Construct a new virtual target of type ty, with the given name and namespace
Sourcepub const fn is_executable(&self) -> bool
pub const fn is_executable(&self) -> bool
Returns true if this target is an executable target
Sourcepub const fn is_library(&self) -> bool
pub const fn is_library(&self) -> bool
Returns true if this target is a non-executable target