pub struct Version {
pub version: SemVer,
pub digest: Option<LexicographicWord>,
}Expand description
The representation of versioning information associated with packages in the package index.
This type provides the means by which dependency resolution can satisfy versioning constraints on packages using either semantic version constraints or explicit package digests simultaneously.
All packages have an associated semantic version. Packages which have been assembled to MAST, also have an associated content digest. However, for the purposes of indexing and dependency resolution, we cannot assume that all packages have a content digest (as they may not have been assembled yet), and so this type is used to represent versions within the index/resolver so that it can:
- Satisfy requirements for a package that has a specific digest
- Record multiple entries in the index for the same semantic version string, when multiple assembled packages with that version are present, disambiguating using the content digest.
- Provide a total ordering for package versions that may or may not include a specific digest
Fields
version: SemVerThe semantic version information
This is the canonical human-facing version for a package.
digest: Option<LexicographicWord>The content digest for this version, if known.
This is the most precise version for a package, and is used to disambiguate multiple instances of a package with the same semantic version, but differing content.
Implementations
Sourceimpl Version
impl Version
Sourcepub fn new(version: SemVer, digest: Word) -> Self
pub fn new(version: SemVer, digest: Word) -> Self
Construct a Version from its component parts.
Sourcepub fn satisfies(&self, requirement: &VersionRequirement) -> bool
pub fn satisfies(&self, requirement: &VersionRequirement) -> bool
Check if this version satisfies the given requirement.
Version requirements are expressed as either a semantic version constraint OR a specific content digest.