pub type MetadataSet = Map<Span<Arc<str>>, Metadata>;Expand description
Represents a set of named metadata tables, where each table is represented by Metadata.
This representation provides spans for the table name, and each entry in that table’s metadata.
Aliased Type
pub struct MetadataSet { /* private fields */ }